# Apex NG client objects

This package contains objects that can be used to get information from the Apex NG backend. The objects contain
methods for creating new items, updating items and querying items.

## Usage

```bash
$ pip install apex_client
```

When installed the plugin will give you access to various objects within Apex NG. This however requires you to have
permissions to view the items (An api user needs to be added to the project).